@@ -1,4 +1,4 @@
 # flake8: noqa
 from .version import __version__
 
-from crontabs.crontabs import Cron, Tab
+from .crontabs import Cron, Tab
